// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.apache.doris

import scala.language.implicitConversions

import org.apache.doris.spark.rdd.DorisSpark
import org.apache.spark.SparkContext

package object spark {
  implicit def sparkContextFunctions(sc: SparkContext) = new SparkContextFunctions(sc)

  class SparkContextFunctions(sc: SparkContext) extends Serializable {
    def dorisRDD(
        tableIdentifier: Option[String] = None,
        query: Option[String] = None,
        cfg: Option[Map[String, String]] = None) =
      DorisSpark.dorisRDD(sc, tableIdentifier, query, cfg)
  }
}
